@@ -4,25 +4,25 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/muesli/coral"
-	mcoral "github.com/muesli/mango-coral"
+	mcoral "github.com/muesli/mango-cobra"
 	"github.com/muesli/roff"
+	"github.com/spf13/cobra"
 )
 
 type manCmd struct {
-	cmd *coral.Command
+	cmd *cobra.Command
 }
 
 func newManCmd() *manCmd {
 	root := &manCmd{}
-	cmd := &coral.Command{
+	cmd := &cobra.Command{
 		Use:                   "man",
 		Short:                 "Generates GoReleaser's command line manpages",
 		SilenceUsage:          true,
 		DisableFlagsInUseLine: true,
 		Hidden:                true,
-		Args:                  coral.NoArgs,
-		RunE: func(cmd *coral.Command, args []string) error {
+		Args:                  cobra.NoArgs,
+		RunE: func(cmd *cobra.Command, args []string) error {
 			manPage, err := mcoral.NewManPage(1, root.cmd.Root())
 			if err != nil {
 				return err
