@@ -2,7 +2,6 @@ package client
 
 import (
 	"fmt"
-	"io/ioutil"
 	"net/http"
 	"net/http/httptest"
 	"os"
@@ -12,6 +11,7 @@ import (
 
 	"code.gitea.io/sdk/gitea"
 	"github.com/goreleaser/goreleaser/internal/artifact"
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/jarcoal/httpmock"
@@ -26,7 +26,7 @@ type GetInstanceURLSuite struct {
 func (s *GetInstanceURLSuite) TestWithScheme() {
 	t := s.T()
 	rootURL := "https://gitea.com"
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		GiteaURLs: config.GiteaURLs{
 			API: rootURL + "/api/v1",
 		},
@@ -39,7 +39,7 @@ func (s *GetInstanceURLSuite) TestWithScheme() {
 
 func (s *GetInstanceURLSuite) TestParseError() {
 	t := s.T()
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		GiteaURLs: config.GiteaURLs{
 			API: "://wrong.gitea.com",
 		},
@@ -52,7 +52,7 @@ func (s *GetInstanceURLSuite) TestParseError() {
 
 func (s *GetInstanceURLSuite) TestNoScheme() {
 	t := s.T()
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		GiteaURLs: config.GiteaURLs{
 			API: "gitea.com",
 		},
@@ -65,7 +65,7 @@ func (s *GetInstanceURLSuite) TestNoScheme() {
 
 func (s *GetInstanceURLSuite) TestEmpty() {
 	t := s.T()
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		GiteaURLs: config.GiteaURLs{
 			API: "",
 		},
@@ -79,7 +79,7 @@ func (s *GetInstanceURLSuite) TestEmpty() {
 func (s *GetInstanceURLSuite) TestTemplate() {
 	t := s.T()
 	rootURL := "https://gitea.mycompany.com"
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		Env: []string{
 			fmt.Sprintf("GORELEASER_TEST_GITAEA_URLS_API=%s", rootURL),
 		},
@@ -95,7 +95,7 @@ func (s *GetInstanceURLSuite) TestTemplate() {
 
 func (s *GetInstanceURLSuite) TestTemplateMissingValue() {
 	t := s.T()
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		GiteaURLs: config.GiteaURLs{
 			API: "{{ .Env.GORELEASER_NOT_EXISTS }}",
 		},
@@ -108,7 +108,7 @@ func (s *GetInstanceURLSuite) TestTemplateMissingValue() {
 
 func (s *GetInstanceURLSuite) TestTemplateInvalid() {
 	t := s.T()
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		GiteaURLs: config.GiteaURLs{
 			API: "{{.dddddddddd",
 		},
@@ -158,9 +158,8 @@ func (s *GiteaReleasesTestSuite) SetupTest() {
 	s.commit = "some commit hash"
 	s.isDraft = false
 	s.isPrerelease = true
-	s.ctx = &context.Context{
-		Version: "6.6.6",
-		Config: config.Project{
+	s.ctx = testctx.NewWithCfg(
+		config.Project{
 			ProjectName: "project",
 			Release: config.Release{
 				NameTemplate: "{{ .ProjectName }}_{{ .Version }}",
@@ -171,20 +170,18 @@ func (s *GiteaReleasesTestSuite) SetupTest() {
 				Draft: s.isDraft,
 			},
 		},
-		Env: context.Env{},
-		Semver: context.Semver{
-			Major: 6,
-			Minor: 6,
-			Patch: 6,
-		},
-		Git: context.GitInfo{
+		testctx.WithVersion("6.6.6"),
+		testctx.WithGitInfo(context.GitInfo{
 			CurrentTag:  s.tag,
 			Commit:      s.commit,
 			ShortCommit: s.commit[0:2],
 			URL:         "https://gitea.com/goreleaser/goreleaser.git",
+		}),
+		func(ctx *context.Context) {
+			ctx.PreRelease = s.isPrerelease
 		},
-		PreRelease: s.isPrerelease,
-	}
+		testctx.WithSemver(6, 6, 6, ""),
+	)
 	s.releaseID = 666
 	s.releaseURL = fmt.Sprintf("%v/%v", s.releasesURL, s.releaseID)
 	httpmock.RegisterResponder("GET", fmt.Sprintf("%s/api/v1/version", s.url), httpmock.NewStringResponder(200, "{\"version\":\"1.12.0\"}"))
@@ -433,7 +430,7 @@ func (s *GiteaUploadSuite) SetupTest() {
 	t := s.T()
 	s.GiteaReleasesTestSuite.SetupTest()
 	s.artifact = &artifact.Artifact{Name: "ArtifactName"}
-	file, err := ioutil.TempFile(t.TempDir(), "gitea_test_tempfile")
+	file, err := os.CreateTemp(t.TempDir(), "gitea_test_tempfile")
 	require.NoError(t, err)
 	require.NotNil(t, file)
 	t.Cleanup(func() {
@@ -508,7 +505,7 @@ func TestGiteaReleaseURLTemplate(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			ctx := context.New(config.Project{
+			ctx := testctx.NewWithCfg(config.Project{
 				Env: []string{
 					"GORELEASER_TEST_GITEA_URLS_DOWNLOAD=https://gitea.mycompany.com",
 				},
@@ -554,7 +551,7 @@ func TestGiteaGetDefaultBranch(t *testing.T) {
 	}))
 	defer srv.Close()
 
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		GiteaURLs: config.GiteaURLs{
 			API: srv.URL,
 		},
@@ -585,7 +582,7 @@ func TestGiteaGetDefaultBranchErr(t *testing.T) {
 	}))
 	defer srv.Close()
 
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		GiteaURLs: config.GiteaURLs{
 			API: srv.URL,
 		},
@@ -612,7 +609,7 @@ func TestGiteaChangelog(t *testing.T) {
 	}))
 	defer srv.Close()
 
-	ctx := context.New(config.Project{
+	ctx := testctx.NewWithCfg(config.Project{
 		GiteaURLs: config.GiteaURLs{
 			API: srv.URL,
 		},
