@@ -5,6 +5,7 @@ import (
 	"os"
 	"testing"
 
+	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/goreleaser/goreleaser/pkg/context"
@@ -17,7 +18,7 @@ func TestDescription(t *testing.T) {
 
 func TestSetDefaultTokenFiles(t *testing.T) {
 	t.Run("empty config", func(t *testing.T) {
-		ctx := context.New(config.Project{})
+		ctx := testctx.New()
 		setDefaultTokenFiles(ctx)
 		require.Equal(t, "~/.config/goreleaser/github_token", ctx.Config.EnvFiles.GitHubToken)
 		require.Equal(t, "~/.config/goreleaser/gitlab_token", ctx.Config.EnvFiles.GitLabToken)
@@ -25,7 +26,7 @@ func TestSetDefaultTokenFiles(t *testing.T) {
 	})
 	t.Run("custom config config", func(t *testing.T) {
 		cfg := "what"
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			EnvFiles: config.EnvFiles{
 				GitHubToken: cfg,
 			},
@@ -34,7 +35,7 @@ func TestSetDefaultTokenFiles(t *testing.T) {
 		require.Equal(t, cfg, ctx.Config.EnvFiles.GitHubToken)
 	})
 	t.Run("templates", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			ProjectName: "foobar",
 			Env: []string{
 				"FOO=FOO_{{ .Env.BAR }}",
@@ -52,7 +53,7 @@ func TestSetDefaultTokenFiles(t *testing.T) {
 	})
 
 	t.Run("template error", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Env: []string{
 				"FOO={{ .Asss }",
 			},
@@ -61,7 +62,7 @@ func TestSetDefaultTokenFiles(t *testing.T) {
 	})
 
 	t.Run("no token", func(t *testing.T) {
-		ctx := context.New(config.Project{})
+		ctx := testctx.New()
 		require.NoError(t, Pipe{}.Run(ctx))
 		require.Equal(t, ctx.TokenType, context.TokenTypeGitHub)
 	})
@@ -69,9 +70,7 @@ func TestSetDefaultTokenFiles(t *testing.T) {
 
 func TestValidGithubEnv(t *testing.T) {
 	require.NoError(t, os.Setenv("GITHUB_TOKEN", "asdf"))
-	ctx := &context.Context{
-		Config: config.Project{},
-	}
+	ctx := testctx.New()
 	require.NoError(t, Pipe{}.Run(ctx))
 	require.Equal(t, "asdf", ctx.Token)
 	require.Equal(t, context.TokenTypeGitHub, ctx.TokenType)
@@ -81,9 +80,7 @@ func TestValidGithubEnv(t *testing.T) {
 
 func TestValidGitlabEnv(t *testing.T) {
 	require.NoError(t, os.Setenv("GITLAB_TOKEN", "qwertz"))
-	ctx := &context.Context{
-		Config: config.Project{},
-	}
+	ctx := testctx.New()
 	require.NoError(t, Pipe{}.Run(ctx))
 	require.Equal(t, "qwertz", ctx.Token)
 	require.Equal(t, context.TokenTypeGitLab, ctx.TokenType)
@@ -93,9 +90,7 @@ func TestValidGitlabEnv(t *testing.T) {
 
 func TestValidGiteaEnv(t *testing.T) {
 	require.NoError(t, os.Setenv("GITEA_TOKEN", "token"))
-	ctx := &context.Context{
-		Config: config.Project{},
-	}
+	ctx := testctx.New()
 	require.NoError(t, Pipe{}.Run(ctx))
 	require.Equal(t, "token", ctx.Token)
 	require.Equal(t, context.TokenTypeGitea, ctx.TokenType)
@@ -106,9 +101,7 @@ func TestValidGiteaEnv(t *testing.T) {
 func TestInvalidEnv(t *testing.T) {
 	require.NoError(t, os.Unsetenv("GITHUB_TOKEN"))
 	require.NoError(t, os.Unsetenv("GITLAB_TOKEN"))
-	ctx := &context.Context{
-		Config: config.Project{},
-	}
+	ctx := testctx.New()
 	require.Error(t, Pipe{}.Run(ctx))
 	require.EqualError(t, Pipe{}.Run(ctx), ErrMissingToken.Error())
 }
@@ -117,9 +110,7 @@ func TestMultipleEnvTokens(t *testing.T) {
 	require.NoError(t, os.Setenv("GITHUB_TOKEN", "asdf"))
 	require.NoError(t, os.Setenv("GITLAB_TOKEN", "qwertz"))
 	require.NoError(t, os.Setenv("GITEA_TOKEN", "token"))
-	ctx := &context.Context{
-		Config: config.Project{},
-	}
+	ctx := testctx.New()
 	require.Error(t, Pipe{}.Run(ctx))
 	require.EqualError(t, Pipe{}.Run(ctx), "multiple tokens found, but only one is allowed: GITHUB_TOKEN, GITLAB_TOKEN, GITEA_TOKEN\n\nLearn more at https://goreleaser.com/errors/multiple-tokens\n")
 	// so the tests do not depend on each other
@@ -130,25 +121,19 @@ func TestMultipleEnvTokens(t *testing.T) {
 
 func TestEmptyGithubFileEnv(t *testing.T) {
 	require.NoError(t, os.Unsetenv("GITHUB_TOKEN"))
-	ctx := &context.Context{
-		Config: config.Project{},
-	}
+	ctx := testctx.New()
 	require.Error(t, Pipe{}.Run(ctx))
 }
 
 func TestEmptyGitlabFileEnv(t *testing.T) {
 	require.NoError(t, os.Unsetenv("GITLAB_TOKEN"))
-	ctx := &context.Context{
-		Config: config.Project{},
-	}
+	ctx := testctx.New()
 	require.Error(t, Pipe{}.Run(ctx))
 }
 
 func TestEmptyGiteaFileEnv(t *testing.T) {
 	require.NoError(t, os.Unsetenv("GITEA_TOKEN"))
-	ctx := &context.Context{
-		Config: config.Project{},
-	}
+	ctx := testctx.New()
 	require.Error(t, Pipe{}.Run(ctx))
 }
 
@@ -158,13 +143,11 @@ func TestEmptyGithubEnvFile(t *testing.T) {
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
 	require.NoError(t, os.Chmod(f.Name(), 0o377))
-	ctx := &context.Context{
-		Config: config.Project{
-			EnvFiles: config.EnvFiles{
-				GitHubToken: f.Name(),
-			},
+	ctx := testctx.NewWithCfg(config.Project{
+		EnvFiles: config.EnvFiles{
+			GitHubToken: f.Name(),
 		},
-	}
+	})
 	require.EqualError(t, Pipe{}.Run(ctx), fmt.Sprintf("failed to load github token: open %s: permission denied", f.Name()))
 }
 
@@ -174,13 +157,11 @@ func TestEmptyGitlabEnvFile(t *testing.T) {
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
 	require.NoError(t, os.Chmod(f.Name(), 0o377))
-	ctx := &context.Context{
-		Config: config.Project{
-			EnvFiles: config.EnvFiles{
-				GitLabToken: f.Name(),
-			},
+	ctx := testctx.NewWithCfg(config.Project{
+		EnvFiles: config.EnvFiles{
+			GitLabToken: f.Name(),
 		},
-	}
+	})
 	require.EqualError(t, Pipe{}.Run(ctx), fmt.Sprintf("failed to load gitlab token: open %s: permission denied", f.Name()))
 }
 
@@ -190,22 +171,17 @@ func TestEmptyGiteaEnvFile(t *testing.T) {
 	require.NoError(t, err)
 	require.NoError(t, f.Close())
 	require.NoError(t, os.Chmod(f.Name(), 0o377))
-	ctx := &context.Context{
-		Config: config.Project{
-			EnvFiles: config.EnvFiles{
-				GiteaToken: f.Name(),
-			},
+	ctx := testctx.NewWithCfg(config.Project{
+		EnvFiles: config.EnvFiles{
+			GiteaToken: f.Name(),
 		},
-	}
+	})
 	require.EqualError(t, Pipe{}.Run(ctx), fmt.Sprintf("failed to load gitea token: open %s: permission denied", f.Name()))
 }
 
 func TestInvalidEnvChecksSkipped(t *testing.T) {
 	require.NoError(t, os.Unsetenv("GITHUB_TOKEN"))
-	ctx := &context.Context{
-		Config:      config.Project{},
-		SkipPublish: true,
-	}
+	ctx := testctx.New(testctx.SkipPublish)
 	require.NoError(t, Pipe{}.Run(ctx))
 }
 
@@ -213,7 +189,7 @@ func TestInvalidEnvReleaseDisabled(t *testing.T) {
 	require.NoError(t, os.Unsetenv("GITHUB_TOKEN"))
 
 	t.Run("true", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Env: []string{},
 			Release: config.Release{
 				Disable: "true",
@@ -223,7 +199,7 @@ func TestInvalidEnvReleaseDisabled(t *testing.T) {
 	})
 
 	t.Run("tmpl true", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Env: []string{"FOO=true"},
 			Release: config.Release{
 				Disable: "{{ .Env.FOO }}",
@@ -233,7 +209,7 @@ func TestInvalidEnvReleaseDisabled(t *testing.T) {
 	})
 
 	t.Run("tmpl false", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Env: []string{"FOO=true"},
 			Release: config.Release{
 				Disable: "{{ .Env.FOO }}-nope",
@@ -243,7 +219,7 @@ func TestInvalidEnvReleaseDisabled(t *testing.T) {
 	})
 
 	t.Run("tmpl error", func(t *testing.T) {
-		ctx := context.New(config.Project{
+		ctx := testctx.NewWithCfg(config.Project{
 			Release: config.Release{
 				Disable: "{{ .Env.FOO }}",
 			},
